@@ -1,14 +1,16 @@
 from .List import List_
 from .Dict import Dict_
-from typing import Callable, Any, Type
+from typing import Callable, Any, Type, final
 from ._error import CallableError, CallableTypeError, CallableKwargsKeyError, CallableKwargsValueTypeError
+from .Subclass import notSubclass
 
 
 
 
 
 
-
+@final
+@notSubclass
 class Callable_:
 
     def __init__(self, _callable: Callable, args_types: list[Type] = [], kwargs_types: dict[str, list[Type]] = {}, is_class: bool = False):
@@ -67,8 +69,6 @@ class Callable_:
                 raise CallableTypeError(self.__args_types.list_, self.__callable.__name__, args[i], i)
 
 
-
-
     def __check_kwargs(self, kwargs: dict) -> None:
         """
         Check all kwargs type argument in [[...], {'NAME': type}][1]
